function srt02Nullstellen2(varargin)

% srt02Nullstellen.m
%
% Einfluss einer Nullstelle auf das dynamische Verhalten eines Systems 2. Ordnung
% Gezeigt werden die Sprungantworten von 5 Systemen zweiter Ordnung, die sich in den Nullstellen unterscheiden.
%
% 06.11.2001, K. Schmid
% gendert am 19.3.2012, G.Diehm


if nargin == 1
    srt02Nullstellen2_cb(varargin{1});
    return
elseif nargin == 2
    srt02Nullstellen2_cb(varargin{1},varargin{2});
    return
end

if ~isempty(findobj('tag','srtdemo2'))
    close(findobj('tag','srtdemo2'));
end

fig=figure;
scr=get(0,'Screensize');
set(fig,'position',[4 35 scr(3)-8 scr(4)-80],'tag','srtdemo2');

sp1=subplot('position',[0.05 0.15 0.9 0.8]);

sp2=subplot('position',[0.05 0.15 0.9 0.8]);
set(sp2,'visible','off');

% Handles fr Plot in Figure speichern
data.sp1=sp1;
data.sp2=sp2;
set(fig,'userdata',data);

forw=uicontrol(fig,'units','normalized','position',[0.6 0.03 0.15 0.05],'style','pushbutton','string','weiter >','tag','forw');
back=uicontrol(fig,'units','normalized','position',[0.4 0.03 0.15 0.05],'style','pushbutton','string','< zurck','tag','back');
zoom=uicontrol(fig,'units','normalized','position',[0.05 0.03 0.15 0.05],'style','pushbutton','string','''zoom reset''','tag','zoom','callback','srt02Nullstellen(0,1);');
finish=uicontrol(fig,'units','normalized','position',[0.8 0.03 0.15 0.05],'style','pushbutton','string','beenden','tag','finish');


srt02Nullstellen2_cb(1);

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
function srt02Nullstellen2_cb(choice,varargin);

fig=findobj('tag','srtdemo2');
figure(fig);
data=get(fig,'userdata');
sp1=data.sp1;
sp2=data.sp2;
forw=findobj('tag','forw');
back=findobj('tag','back');
finish=findobj('tag','finish');

if choice == 0
    if varargin{1}==1
        subplot(sp1);
        zoom out;
        subplot(sp1);
        zoom out;
    end
    return
end

% Allgemeine Einstellungen

% Grafik
MarkerProperties.MarkerSize = 15;
MarkerProperties.LineWidth = 2;
%
LineProperties.LineWidth 	= 2;
LineProperties.Color		= 'k';
%
AxisProperties.LineWidth	= 2;
AxisProperties.FontSize		= 16;

% Die Pole aller bertragungsfunktionen liegen bei
Pol1 = -1+i;
Pol2 = -1-i;
%
% Die zu vergleichenden bertragungsfunktionen unterscheiden sich durch die Lage ihrer Nullstelle
NullA = [];
NullB = -10;
NullC = -1;
NullD =  0;
NullE =  1;

%
% Die zu diesen Nullstellen gehrenden bertragungsfunktionen sind so definiert, dass sie jeweils die gleiche
% stationre Verstrkung besitzen
sysA = zpk([NullA],[Pol1, Pol2],2);
sysB = zpk([NullB],[Pol1, Pol2],0.2);
sysC = zpk([NullC],[Pol1, Pol2],2);
sysD = zpk([NullD],[Pol1, Pol2],2);
sysE = zpk([NullE],[Pol1, Pol2],-2);
%
% In den Titelzeilen der Bilder wird jeweils angezeigt, welche Nullstelle das aktuelle System hat:
Titel = ['Pole: s1 = ',num2str(Pol1),', s2 = ',num2str(Pol2),'; Nullstelle s3 = '];
TitelA = [Titel,'--'];
TitelB = [Titel,num2str(NullB)];
TitelC = [Titel,num2str(NullC)];
TitelD = [Titel,num2str(NullD)];
TitelE = [Titel,num2str(NullE)];


% Angezeigt werden die Pol-Nullstellen-Kombination des jeweiligen Systems und die Sprungantwort.
% Da die Pole bei allen Systemen gleich sind, werden diese zunchst angezeigt:
if choice == 1
    subplot(sp1);
    set(sp1,'visible','on');
    set(sp2,'visible','off');
    % erster Pol
    plot(real(Pol1), imag(Pol1), 'r:x',MarkerProperties);
    hold on;
    % zweiter Pol
    plot(real(Pol2), imag(Pol2), 'r:x',MarkerProperties);
    % Zeichnen des Achsenkreuzes
    l1=line([0 0],[-2 2]);
    set(l1,LineProperties);
    l2=line([-11 2],[0 0]);
    set(l2,LineProperties);
    axis([-11 2 -2 2]);
    title(TitelA);
    hold off;
    zoom off;
end

% Die Sprungantworten werden in einem anderen Bild angezeigt
if choice == 2
    subplot(sp2);
    set(sp1,'visible','off');
    set(sp2,'visible','on');
    % --- System A: keine Nullstelle
    set(gca, AxisProperties)
    title(TitelA);

    step(sysA,'b');
    zoom on;
    title(TitelA);
end

% --- System B: eine Nullstelle bei s3 = -10
if choice == 3
    subplot(sp1);
    set(sp1,'visible','on');
    set(sp2,'visible','off');
    % erster Pol
    plot(real(Pol1), imag(Pol1), 'r:x',MarkerProperties);
    hold on;
    % zweiter Pol
    plot(real(Pol2), imag(Pol2), 'r:x',MarkerProperties);
    % Zeichnen des Achsenkreuzes
    l1=line([0 0],[-2 2]);
    set(l1,LineProperties);
    l2=line([-11 2],[0 0]);
    set(l2,LineProperties);
    axis([-11 2 -2 2]);
    fNullB = plot(NullB,0,'b:o',MarkerProperties);
    title(TitelB);
    hold off;
    zoom off;
end
%

if choice == 4
    subplot(sp2);
    set(sp1,'visible','off');
    set(sp2,'visible','on');
    %
    step(sysA,'k:',sysB,'b');
    zoom on;
    title(TitelB);
end
%

% --- System C: eine Nullstelle bei s3 = -1
if choice == 5
    subplot(sp1);
    set(sp1,'visible','on');
    set(sp2,'visible','off');
    % erster Pol
    plot(real(Pol1), imag(Pol1), 'r:x',MarkerProperties);
    hold on;
    % zweiter Pol
    plot(real(Pol2), imag(Pol2), 'r:x',MarkerProperties);
    % Zeichnen des Achsenkreuzes
    l1=line([0 0],[-2 2]);
    set(l1,LineProperties);
    l2=line([-11 2],[0 0]);
    set(l2,LineProperties);
    axis([-11 2 -2 2]);
    fNullC = plot(NullC,0,'b:o',MarkerProperties);
    title(TitelC);
    hold off;
    zoom off;
end
%
%
if choice == 6
    subplot(sp2);
    set(sp1,'visible','off');
    set(sp2,'visible','on');
    %
    step(sysA,'k:',sysB,'k:',sysC,'b');
    title(TitelC);
    zoom on;
end

% --- System D: eine Nullstelle bei s3 = 0
if choice == 7
    subplot(sp1);
    set(sp1,'visible','on');
    set(sp2,'visible','off');
    % erster Pol
    plot(real(Pol1), imag(Pol1), 'r:x',MarkerProperties);
    hold on;
    % zweiter Pol
    plot(real(Pol2), imag(Pol2), 'r:x',MarkerProperties);
    % Zeichnen des Achsenkreuzes
    l1=line([0 0],[-2 2]);
    set(l1,LineProperties);
    l2=line([-11 2],[0 0]);
    set(l2,LineProperties);
    axis([-11 2 -2 2]);
    fNullD = plot(NullD,0,'b:o',MarkerProperties);
    title(TitelD);
    hold off;
    zoom off;
end
%
if choice == 8
    subplot(sp2);
    set(sp1,'visible','off');
    set(sp2,'visible','on');
    %
    step(sysA,'k:',sysB,'k:',sysC,'k:',sysD,'b');
    title(TitelD);
    zoom on;
end
%

% --- System E: eine Nullstelle bei s3 = +1
if choice == 9
    subplot(sp1);
    set(sp1,'visible','on');
    set(sp2,'visible','off');
    % erster Pol
    plot(real(Pol1), imag(Pol1), 'r:x',MarkerProperties);
    hold on;
    % zweiter Pol
    plot(real(Pol2), imag(Pol2), 'r:x',MarkerProperties);
    % Zeichnen des Achsenkreuzes
    l1=line([0 0],[-2 2]);
    set(l1,LineProperties);
    l2=line([-11 2],[0 0]);
    set(l2,LineProperties);
    axis([-11 2 -2 2]);
    fNullE = plot(NullE,0,'b:o',MarkerProperties);
    title(TitelE);
    hold off;
    zoom off;
end
%

if choice == 10
    subplot(sp2);
    set(sp1,'visible','off');
    set(sp2,'visible','on');
    %
    step(sysA,'k:',sysB,'k:',sysC,'r:',sysD,'k:',sysE,'b');
    title(TitelE);
    zoom on;
    %
end

if choice == 11
    figure('tag','demo2_bode');bode(sysE,sysC,'r*');legend('NSte bei 1','NSte bei -1');
    %
end


max_schritte=11;
if choice < max_schritte
    set(forw,'callback',['srt02Nullstellen2(' num2str(choice+1) ')'],'enable','on');
    set(finish,'enable','off');
else
    set(forw,'enable','off');
    set(finish,'callback',['close(findobj(''tag'',''demo2_bode''),findobj(''tag'',''srtdemo2''))'],'enable','on');
end
if choice > 1
    set(back,'callback',['srt02Nullstellen2(' num2str(choice-1) ')'],'enable','on');
else
    set(back,'enable','off');
end
return
